@@ -1,4 +1,4 @@
-/* $Id: record_lexical.h,v 1.3 2005/06/30 14:22:47 oohara Exp $ */
+/* $Id: record_lexical.h,v 1.5 2011/08/24 16:30:17 oohara Exp $ */
 
 #ifndef __DANGEN_RECORD_LEXICAL_H__
 #define __DANGEN_RECORD_LEXICAL_H__
@@ -6,11 +6,13 @@
 /* FILE */
 #include <stdio.h>
 
+/* yylineno */
+extern int record_lineno;
+
 /* yylex */
 int record_lex(void);
-
-int record_get_line_number(void);
-void record_clear_line_number(void);
+/* yylex_destroy */
+int record_lex_destroy(void);
 
 void record_read_from_file(FILE *file);
 void record_read_from_string(const char *string);
