@@ -1,4 +1,4 @@
-/* $Id: empty-wind.c,v 1.213 2004/09/06 21:18:23 oohara Exp $ */
+/* $Id: empty-wind.c,v 1.214 2011/08/23 19:46:22 oohara Exp $ */
 /* [very hard] Empty Wind */
 
 #include <stdio.h>
@@ -1098,8 +1098,6 @@ empty_wind_spiral_act(tenm_object *my, const tenm_object *player)
   int theta;
   double x;
   double y;
-  double dx;
-  double dy;
   
   /* sanity check */
   if (my == NULL)
@@ -1116,8 +1114,6 @@ empty_wind_spiral_act(tenm_object *my, const tenm_object *player)
       x = my->x + 50.0 * tenm_cos(theta);
       y = ((double) WINDOW_HEIGHT) + 10.0 - (double) (i * 9)
         + 50.0 * tenm_sin(theta);
-      dx = 25.0 * tenm_cos(theta);
-      dy = 25.0 * tenm_sin(theta);
 
       tenm_table_add(laser_angle_new(x, y, 9.0, theta + my->count[3] * 150,
                                      25.0, 1));
