@@ -1,4 +1,4 @@
-/* $Id: hugin.c,v 1.71 2005/06/26 15:56:28 oohara Exp $ */
+/* $Id: hugin.c,v 1.72 2011/08/23 20:07:50 oohara Exp $ */
 /* [very easy] Hugin */
 
 #include <stdio.h>
@@ -552,7 +552,7 @@ hugin_draw(tenm_object *my, int priority)
     }
   }
 
-  return 0;
+  return status;
 }
 
 /* return 1 (true) or 0 (false) */
@@ -1015,12 +1015,12 @@ munin_draw(tenm_object *my, int priority)
     if (draw_string(((int) my->x) - 10, (int) my->y,
                     temp, (int) strlen(temp)) != 0)
     {
-      fprintf(stderr, "hugin_draw: draw_string failed\n");
+      fprintf(stderr, "munin_draw: draw_string failed\n");
       status = 1;
     }
   }
 
-  return 0;
+  return status;
 }
 
 /* return 1 (true) or 0 (false) */
