@@ -875,10 +875,10 @@ static int
 net_can_howl_core_draw(tenm_object *my, int priority)
 {
   int i;
-  int a_x;
-  int a_y;
-  int b_x;
-  int b_y;
+  double a_x;
+  double a_y;
+  double b_x;
+  double b_y;
   double dx;
   double dy;
   double length;
